<?php

function getConfigurationFile($fileType) {
    $headers         = getallheaders();
    $extClientPreset = getValueFromEnv("EXTERNAL_CLIENT_PRESET");
    $environmentPath = "";

    $client     = isset($headers['x-client-env'])  ? $headers['x-client-env']  : null;
    $clientType = isset($headers['x-client-type']) ? $headers['x-client-type'] : null;

    if(empty($extClientPreset) && (empty($client) || empty($clientType))) { 
        errorMessage("Invalid client preset");        
    }

    if($clientType == 'saas' || $clientType == 'hosting') {
        return json_encode([
            "driver"        => "oci8",
            "host"          => "",
            "port"          => "",
            "user"          => "/",
            "password"      => "",
            "dbname"        => $client,
            "charset"       => "AL32UTF8",
            "service"       => true,
            "sessionMode"   => "OCI_CRED_EXT"
        ]);   
    } else {
        $environmentPath = __DIR__ . "/../clients/external/$extClientPreset/$fileType";   
    }
    
    if(!file_exists($environmentPath)) {
        errorMessage("Invalid $fileType file");
    }
    
    return file_get_contents($environmentPath);
}


function getValueFromEnv($key, $value = "") {
    if(!file_exists(__DIR__ . "/../env.ini")) {
       errorMessage("Invalid .env file");
    }

    $envFile = fopen(__DIR__ . "/../env.ini", "r");
    while(!feof($envFile)) {
        $line         = fgets($envFile);
        $tmp          = explode('=', $line);
        $currentKey   = $tmp[0];
        $currentValue = trim($tmp[1]);
        if($currentKey == $key) {
            $value = $currentValue;
            break;                
        }
    }
    
    fclose($envFile);
    return $value;
}

function getClientName() {
    $headers = getallheaders();
    $externalClientName = getValueFromEnv('EXTERNAL_CLIENT_PRESENT');
    return isset($headers['x-client-name']) ? $headers['x-client-name'] : $externalClientName;
}


function errorMessage($error) {
    echo json_encode([
        'error'   => true,
        'message' => $error,
        'data'    => []
    ]); 
    die;
}
