<?php

namespace App\Service;

use App\Exception;

class ConsumerService {
    
    private $util;
    private $factory;
    private $branchFactory;
    
    public function __construct (\App\Util\Util $util, 
                                 \App\Factory\ConsumerFactory $factory,
                                 \App\Factory\BranchFactory $branchFactory) {

        $this->util          = $util;
        $this->factory       = $factory;
        $this->branchFactory = $branchFactory;
    }
    
    private function findConsumer($order, $standardClient, $generalParams){
        $consumer = [];
        
        if (!empty($order["customer"]["email"])) {
            $consumer = $this->factory->getConsumerByEmail($order["customer"]["email"], $standardClient);
        }
        
        if (empty($consumer) && !empty($customer["telephone"])) {
            $phone = preg_replace("/\s+/", "", $customer["telephone"]);
            if (!empty($phone)) {
                $consumer = $this->factory->getConsumerByPhone($phone, $standardClient);
            }
        }
        
        if (empty($consumer)) {
            $consumer["customer"]["clientCode"] = $standardClient;
            if(empty($order["address"])) {
                throw new Exception\ValidationException("Não foi possível validar o endereço do pedido.");
            }
            
            $consumer = $this->registerConsumer($generalParams, $order["customer"], $order["address"]);
        }
        
        return $consumer;
    }
    
    public function registerConsumer ($generalParams, $customer, $address) {
        $stdClient = $this->branchFactory->getStandartClient($generalParams["CDFILIAL"]);
        $consumerT = $this->branchFactory->getStandartConsumerType($generalParams["CDFILIAL"]);
        $consumer  = "SDE".$this->util->newCode("CONSUMIDOR".$stdClient["CDCLIENTE"], 18);
        
        $consumerDetails["CDCONSUMIDOR"] = $consumer;
        $consumerDetails["CDMUNICIPIO"]  = $this->factory->getCityCode($address["state"], $address["city"]);
        
        if (empty($consumerDetails["CDMUNICIPIO"]))
            $consumerDetails["CDMUNICIPIO"] = $this->branchFactory->getBranchCityCode($generalParams["CDFILIAL"]);
        
        $mergeCandidates = array($stdClient, $consumerT);
        
        foreach ($mergeCandidates as $candidate) 
            $consumerDetails = array_merge($consumerDetails, $candidate);
        
        $consumer = $this->factory->registerConsumer(array_merge($consumerDetails, $customer, $address));
        
        return $consumer;
    }
    
    public function processConsumer ($generalParams, $order) {

        $standardClient = $this->branchFactory->getStandartClient($generalParams["CDFILIAL"])['CDCLIENTE'];
	    $consumer       = $this->findConsumer($order, $standardClient, $generalParams);
        $consumer["CDBAIRRO"] = $this->factory->getNeighborhoodCode($order["address"]);
        $consumer["DSBAIRRO"] = $order['address']['neighborhood'];

        if (empty($consumer["CDMUNICIPIO"])) 
            $consumer["CDMUNICIPIO"] = $this->factory->getCityCode($order["address"]["state"], $order["address"]["city"]);
        
        return $consumer;
    }
}
